==> nextcloud-app-deck-1%3A0.8.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/mk.js <==
OC.L10N.register(
    "deck",
    {
    "Hours" : "Часови",
    "Minutes" : "Минути",
    "Personal" : "Лично",
    "Finished" : "Завршено",
    "Done" : "Готово",
    "The file was uploaded" : "Датотеката е прикачена",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која беше специфицирана во HTML формата",
    "The file was only partially uploaded" : "Датотеката беше само делумно прикачена",
    "No file was uploaded" : "Нема прикачено дадотека",
    "Missing a temporary folder" : "Недостасува привремена папка",
    "Could not write file to disk" : "Неможе да се запишува на дискот",
    "A PHP extension stopped the file upload" : "PHP додаток го стопираше прикачувањето на датотеката",
    "Submit" : "Испрати",
    "Actions" : "Акции",
    "Close" : "Затвори",
    "Sharing" : "Споделување",
    "Tags" : "Ознаки",
    "Group" : "Група",
    "Circle" : "Круг",
    "Loading" : "Се вчитува",
    "Edit" : "Уреди",
    "Share" : "Сподели",
    "Create" : "Креирај",
    "Create a new tag" : "Креирајте нова ознака",
    "Status" : "Статус",
    "Title" : "Наслов",
    "Cancel upload" : "Откажи прикачување",
    "by" : "од",
    "Modified:" : "Изменето:",
    "Created:" : "Создадено:",
    "Description" : "Опис",
    "Saved" : "Зачувано",
    "Upload attachment" : "Прикачи прилог",
    "Settings" : "Параметри"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");

==> nextcloud-app-deck-1%3A1.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/deck/l10n/mk.js <==
OC.L10N.register(
    "deck",
    {
    "Personal" : "Лично",
    "Finished" : "Завршено",
    "copy" : "копирај",
    "Done" : "Готово",
    "The file was uploaded" : "Датотеката е прикачена",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Подигнатата датотека ја надминува upload_max_filesize директивата во php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Големината на датотеката ја надминува MAX_FILE_SIZE директивата која беше специфицирана во HTML формата",
    "The file was only partially uploaded" : "Датотеката беше само делумно прикачена",
    "No file was uploaded" : "Нема прикачено дадотека",
    "Missing a temporary folder" : "Недостасува привремена папка",
    "Could not write file to disk" : "Неможе да се запишува на дискот",
    "A PHP extension stopped the file upload" : "PHP додаток го стопираше прикачувањето на датотеката",
    "Cancel" : "Откажи",
    "Details" : "Детали",
    "Sharing" : "Споделување",
    "Tags" : "Ознаки",
    "Can edit" : "Може да се уредува",
    "Can share" : "Can share",
    "Delete" : "Избриши",
    "Edit" : "Уреди",
    "Description" : "Опис",
    "Comments" : "Коментари",
    "Modified" : "Изменето",
    "Upload attachment" : "Прикачи прилог",
    "Save" : "Зачувај",
    "Reply" : "Одговор",
    "Update" : "Ажурирај",
    "(group)" : "(group)",
    "seconds ago" : "пред неколку секунди",
    "Settings" : "Параметри",
    "Share" : "Сподели",
    "Options" : "Опции",
    "An error occurred" : "Настана грешка"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
